==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/proc/ProcCreateCmaterialOrderCmaterialOrderBean.java <==
package global.hh.openapi.sdk.api.bean.proc;

        import java.util.List;
        import java.util.List;

/**
 * @description: 分销平台外部物料订单创建接口
 * @author: 777771
 * @date: 2023-18-27 10:18:35
 */
public class ProcCreateCmaterialOrderCmaterialOrderBean {

    /**
     * 费用申请单号
     */
    private String costOrderNo;

    /**
     * 邮编
     */
    private String postalCode;

    /**
     * 会员收货信息实体，当memberOrder=true 时必传
     */
    private List<ProcCreateCmaterialOrderMemberItem> members;

    /**
     * 是否会员收货订单
     */
    private Boolean memberOrder;

    /**
     * 物料订单明细实体对象
     */
    private List<ProcCreateCmaterialOrderDetailItem> details;

    /**
     * 乡镇/街道((编码)
     */
    private String townCode;

    /**
     * 乡镇/街道((名称)
     */
    private String town;

    /**
     * 区/县(名称)
     */
    private String area;

    /**
     * 市(名称)
     */
    private String city;

    /**
     * 省(名称)
     */
    private String province;

    /**
     * 收货人详细地址
     */
    private String receiveAddress;

    /**
     * 收货人联系方式
     */
    private String receivePhone;

    /**
     * 收货人名称
     */
    private String receiveMan;

    /**
     * 收货人类型(0-办事处, 1-经销商，2-会员，3-智采专用)
     */
    private String receiveType;

    /**
     * 外部平台单据号
     */
    private String platformOrderNo;

    /**
     * 下单方式(1-页面下单，2-导入订单，3-接口下单)
     */
    private String orderType;

    /**
     * 下单人工号
     */
    private String createById;

    /**
     * 订单备注
     */
    private String remark;

    /**
     * 订单总金额
     */
    private String payPrice;

    /**
     * 单据类型(0-集团物料(物料订购)，1-集团物料(礼品分类)，2-京东集采, 3-货补物料， 4-智采订购)
     */
    private String type;

    public ProcCreateCmaterialOrderCmaterialOrderBean(){
    }

    public ProcCreateCmaterialOrderCmaterialOrderBean(String costOrderNo,String postalCode,List<ProcCreateCmaterialOrderMemberItem> members,Boolean memberOrder,List<ProcCreateCmaterialOrderDetailItem> details,String townCode,String town,String area,String city,String province,String receiveAddress,String receivePhone,String receiveMan,String receiveType,String platformOrderNo,String orderType,String createById,String remark,String payPrice,String type){
        this.costOrderNo=costOrderNo;
        this.postalCode=postalCode;
        this.members=members;
        this.memberOrder=memberOrder;
        this.details=details;
        this.townCode=townCode;
        this.town=town;
        this.area=area;
        this.city=city;
        this.province=province;
        this.receiveAddress=receiveAddress;
        this.receivePhone=receivePhone;
        this.receiveMan=receiveMan;
        this.receiveType=receiveType;
        this.platformOrderNo=platformOrderNo;
        this.orderType=orderType;
        this.createById=createById;
        this.remark=remark;
        this.payPrice=payPrice;
        this.type=type;
    }

    private String getCostOrderNo() {
        return costOrderNo;
    }

    private void setCostOrderNo(String costOrderNo) {
        this.costOrderNo = costOrderNo;
    }
    private String getPostalCode() {
        return postalCode;
    }

    private void setPostalCode(String postalCode) {
        this.postalCode = postalCode;
    }
    private List<ProcCreateCmaterialOrderMemberItem> getMembers() {
        return members;
    }

    private void setMembers(List<ProcCreateCmaterialOrderMemberItem> members) {
        this.members = members;
    }
    private Boolean getMemberOrder() {
        return memberOrder;
    }

    private void setMemberOrder(Boolean memberOrder) {
        this.memberOrder = memberOrder;
    }
    private List<ProcCreateCmaterialOrderDetailItem> getDetails() {
        return details;
    }

    private void setDetails(List<ProcCreateCmaterialOrderDetailItem> details) {
        this.details = details;
    }
    private String getTownCode() {
        return townCode;
    }

    private void setTownCode(String townCode) {
        this.townCode = townCode;
    }
    private String getTown() {
        return town;
    }

    private void setTown(String town) {
        this.town = town;
    }
    private String getArea() {
        return area;
    }

    private void setArea(String area) {
        this.area = area;
    }
    private String getCity() {
        return city;
    }

    private void setCity(String city) {
        this.city = city;
    }
    private String getProvince() {
        return province;
    }

    private void setProvince(String province) {
        this.province = province;
    }
    private String getReceiveAddress() {
        return receiveAddress;
    }

    private void setReceiveAddress(String receiveAddress) {
        this.receiveAddress = receiveAddress;
    }
    private String getReceivePhone() {
        return receivePhone;
    }

    private void setReceivePhone(String receivePhone) {
        this.receivePhone = receivePhone;
    }
    private String getReceiveMan() {
        return receiveMan;
    }

    private void setReceiveMan(String receiveMan) {
        this.receiveMan = receiveMan;
    }
    private String getReceiveType() {
        return receiveType;
    }

    private void setReceiveType(String receiveType) {
        this.receiveType = receiveType;
    }
    private String getPlatformOrderNo() {
        return platformOrderNo;
    }

    private void setPlatformOrderNo(String platformOrderNo) {
        this.platformOrderNo = platformOrderNo;
    }
    private String getOrderType() {
        return orderType;
    }

    private void setOrderType(String orderType) {
        this.orderType = orderType;
    }
    private String getCreateById() {
        return createById;
    }

    private void setCreateById(String createById) {
        this.createById = createById;
    }
    private String getRemark() {
        return remark;
    }

    private void setRemark(String remark) {
        this.remark = remark;
    }
    private String getPayPrice() {
        return payPrice;
    }

    private void setPayPrice(String payPrice) {
        this.payPrice = payPrice;
    }
    private String getType() {
        return type;
    }

    private void setType(String type) {
        this.type = type;
    }
}

==> biostime-openapi-sdk-1.5.8.6-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/proc/ProcCreateCmaterialOrderCmaterialOrderBean.java <==
package global.hh.openapi.sdk.api.bean.proc;

        import java.util.List;
        import java.util.List;

/**
 * @description: 分销平台外部物料订单创建接口
 * @author: 777771
 * @date: 2023-18-27 10:18:35
 */
public class ProcCreateCmaterialOrderCmaterialOrderBean {

    /**
     * 费用申请单号
     */
    private String costOrderNo;

    /**
     * 邮编
     */
    private String postalCode;

    /**
     * 会员收货信息实体，当memberOrder=true 时必传
     */
    private List<ProcCreateCmaterialOrderMemberItem> members;

    /**
     * 是否会员收货订单
     */
    private Boolean memberOrder;

    /**
     * 物料订单明细实体对象
     */
    private List<ProcCreateCmaterialOrderDetailItem> details;

    /**
     * 乡镇/街道((编码)
     */
    private String townCode;

    /**
     * 乡镇/街道((名称)
     */
    private String town;

    /**
     * 区/县(名称)
     */
    private String area;

    /**
     * 市(名称)
     */
    private String city;

    /**
     * 省(名称)
     */
    private String province;

    /**
     * 收货人详细地址
     */
    private String receiveAddress;

    /**
     * 收货人联系方式
     */
    private String receivePhone;

    /**
     * 收货人名称
     */
    private String receiveMan;

    /**
     * 收货人类型(0-办事处, 1-经销商，2-会员，3-智采专用)
     */
    private String receiveType;

    /**
     * 外部平台单据号
     */
    private String platformOrderNo;

    /**
     * 下单方式(1-页面下单，2-导入订单，3-接口下单)
     */
    private String orderType;

    /**
     * 下单人工号
     */
    private String createById;

    /**
     * 订单备注
     */
    private String remark;

    /**
     * 订单总金额
     */
    private String payPrice;

    /**
     * 单据类型(0-集团物料(物料订购)，1-集团物料(礼品分类)，2-京东集采, 3-货补物料， 4-智采订购)
     */
    private String type;

    public ProcCreateCmaterialOrderCmaterialOrderBean(){
    }

    public ProcCreateCmaterialOrderCmaterialOrderBean(String costOrderNo,String postalCode,List<ProcCreateCmaterialOrderMemberItem> members,Boolean memberOrder,List<ProcCreateCmaterialOrderDetailItem> details,String townCode,String town,String area,String city,String province,String receiveAddress,String receivePhone,String receiveMan,String receiveType,String platformOrderNo,String orderType,String createById,String remark,String payPrice,String type){
        this.costOrderNo=costOrderNo;
        this.postalCode=postalCode;
        this.members=members;
        this.memberOrder=memberOrder;
        this.details=details;
        this.townCode=townCode;
        this.town=town;
        this.area=area;
        this.city=city;
        this.province=province;
        this.receiveAddress=receiveAddress;
        this.receivePhone=receivePhone;
        this.receiveMan=receiveMan;
        this.receiveType=receiveType;
        this.platformOrderNo=platformOrderNo;
        this.orderType=orderType;
        this.createById=createById;
        this.remark=remark;
        this.payPrice=payPrice;
        this.type=type;
    }

    public String getCostOrderNo() {
        return costOrderNo;
    }

    public void setCostOrderNo(String costOrderNo) {
        this.costOrderNo = costOrderNo;
    }
    public String getPostalCode() {
        return postalCode;
    }

    public void setPostalCode(String postalCode) {
        this.postalCode = postalCode;
    }
    public List<ProcCreateCmaterialOrderMemberItem> getMembers() {
        return members;
    }

    public void setMembers(List<ProcCreateCmaterialOrderMemberItem> members) {
        this.members = members;
    }
    public Boolean getMemberOrder() {
        return memberOrder;
    }

    public void setMemberOrder(Boolean memberOrder) {
        this.memberOrder = memberOrder;
    }
    public List<ProcCreateCmaterialOrderDetailItem> getDetails() {
        return details;
    }

    public void setDetails(List<ProcCreateCmaterialOrderDetailItem> details) {
        this.details = details;
    }
    public String getTownCode() {
        return townCode;
    }

    public void setTownCode(String townCode) {
        this.townCode = townCode;
    }
    public String getTown() {
        return town;
    }

    public void setTown(String town) {
        this.town = town;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }
    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }
    public String getReceiveAddress() {
        return receiveAddress;
    }

    public void setReceiveAddress(String receiveAddress) {
        this.receiveAddress = receiveAddress;
    }
    public String getReceivePhone() {
        return receivePhone;
    }

    public void setReceivePhone(String receivePhone) {
        this.receivePhone = receivePhone;
    }
    public String getReceiveMan() {
        return receiveMan;
    }

    public void setReceiveMan(String receiveMan) {
        this.receiveMan = receiveMan;
    }
    public String getReceiveType() {
        return receiveType;
    }

    public void setReceiveType(String receiveType) {
        this.receiveType = receiveType;
    }
    public String getPlatformOrderNo() {
        return platformOrderNo;
    }

    public void setPlatformOrderNo(String platformOrderNo) {
        this.platformOrderNo = platformOrderNo;
    }
    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }
    public String getCreateById() {
        return createById;
    }

    public void setCreateById(String createById) {
        this.createById = createById;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getPayPrice() {
        return payPrice;
    }

    public void setPayPrice(String payPrice) {
        this.payPrice = payPrice;
    }
    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }
}
